pub unsafe trait ReadOnlySystemParam: SystemParam { }Expand description
A SystemParam that only reads a given World.
Safety
This must only be implemented for SystemParam impls that exclusively read the World passed in to SystemParam::get_param
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
Implementations on Foreign Types
impl ReadOnlySystemParam for ()
impl<P: ReadOnlySystemParam> ReadOnlySystemParam for (P₁, P₂, …, Pₙ)
This trait is implemented for tuples up to 17 items long.
impl<T: ?Sized> ReadOnlySystemParam for PhantomData<T>
impl<T: ReadOnlySystemParam> ReadOnlySystemParam for Option<T>
impl<T: ReadOnlySystemParam> ReadOnlySystemParam for Result<T, SystemParamValidationError>
Implementors
impl ReadOnlySystemParam for ExclusiveMarker
impl ReadOnlySystemParam for FilteredResources<'_, '_>
impl ReadOnlySystemParam for NonSendMarker
impl ReadOnlySystemParam for SystemChangeTick
impl ReadOnlySystemParam for SystemName
impl ReadOnlySystemParam for WorldId
impl<'a, 'b, D: ReadOnlyQueryData + 'static, F: QueryFilter + 'static> ReadOnlySystemParam for Single<'a, 'b, D, F>
impl<'a, T: Resource> ReadOnlySystemParam for Res<'a, T>
impl<'a> ReadOnlySystemParam for &'a Archetypes
impl<'a> ReadOnlySystemParam for &'a Bundles
impl<'a> ReadOnlySystemParam for &'a Components
impl<'a> ReadOnlySystemParam for &'a Entities
impl<'a> ReadOnlySystemParam for &'a EntityAllocator
impl<'a> ReadOnlySystemParam for &'a RemovedComponentMessages
impl<'s, T: FromWorld + Send + 'static> ReadOnlySystemParam for Local<'s, T>
impl<'w, 's, D: ReadOnlyQueryData + 'static, F: QueryFilter + 'static> ReadOnlySystemParam for Populated<'w, 's, D, F>
impl<'w, 's, D: ReadOnlyQueryData + 'static, F: QueryFilter + 'static> ReadOnlySystemParam for Query<'w, 's, D, F>
impl<'w, 's, M: Message> ReadOnlySystemParam for MessageMutator<'w, 's, M>where
Local<'s, MessageCursor<M>>: ReadOnlySystemParam,
ResMut<'w, Messages<M>>: ReadOnlySystemParam,
impl<'w, 's, M: Message> ReadOnlySystemParam for MessageReader<'w, 's, M>
impl<'w, 's, M: Message> ReadOnlySystemParam for MessageWriter<'w, M>
impl<'w, 's, P0, P1, P2, P3, P4, P5, P6, P7> ReadOnlySystemParam for ParamSet<'w, 's, (P0, P1, P2, P3, P4, P5, P6, P7)>where
P0: ReadOnlySystemParam,
P1: ReadOnlySystemParam,
P2: ReadOnlySystemParam,
P3: ReadOnlySystemParam,
P4: ReadOnlySystemParam,
P5: ReadOnlySystemParam,
P6: ReadOnlySystemParam,
P7: ReadOnlySystemParam,
impl<'w, 's, P0, P1, P2, P3, P4, P5, P6> ReadOnlySystemParam for ParamSet<'w, 's, (P0, P1, P2, P3, P4, P5, P6)>where
P0: ReadOnlySystemParam,
P1: ReadOnlySystemParam,
P2: ReadOnlySystemParam,
P3: ReadOnlySystemParam,
P4: ReadOnlySystemParam,
P5: ReadOnlySystemParam,
P6: ReadOnlySystemParam,
impl<'w, 's, P0, P1, P2, P3, P4, P5> ReadOnlySystemParam for ParamSet<'w, 's, (P0, P1, P2, P3, P4, P5)>where
P0: ReadOnlySystemParam,
P1: ReadOnlySystemParam,
P2: ReadOnlySystemParam,
P3: ReadOnlySystemParam,
P4: ReadOnlySystemParam,
P5: ReadOnlySystemParam,
impl<'w, 's, P0, P1, P2, P3, P4> ReadOnlySystemParam for ParamSet<'w, 's, (P0, P1, P2, P3, P4)>where
P0: ReadOnlySystemParam,
P1: ReadOnlySystemParam,
P2: ReadOnlySystemParam,
P3: ReadOnlySystemParam,
P4: ReadOnlySystemParam,
impl<'w, 's, P0, P1, P2, P3> ReadOnlySystemParam for ParamSet<'w, 's, (P0, P1, P2, P3)>where
P0: ReadOnlySystemParam,
P1: ReadOnlySystemParam,
P2: ReadOnlySystemParam,
P3: ReadOnlySystemParam,
impl<'w, 's, P0, P1, P2> ReadOnlySystemParam for ParamSet<'w, 's, (P0, P1, P2)>
impl<'w, 's, P0, P1> ReadOnlySystemParam for ParamSet<'w, 's, (P0, P1)>where
P0: ReadOnlySystemParam,
P1: ReadOnlySystemParam,
impl<'w, 's, P0> ReadOnlySystemParam for ParamSet<'w, 's, (P0,)>where
P0: ReadOnlySystemParam,
impl<'w, 's, P: ReadOnlySystemParam + 'static> ReadOnlySystemParam for StaticSystemParam<'w, 's, P>
impl<'w, 's, T: Component> ReadOnlySystemParam for ComponentIdFor<'s, T>where
Local<'s, InitComponentId<T>>: ReadOnlySystemParam,
impl<'w, 's, T: Component> ReadOnlySystemParam for RemovedComponents<'w, 's, T>where
ComponentIdFor<'s, T>: ReadOnlySystemParam,
Local<'s, RemovedComponentReader<T>>: ReadOnlySystemParam,
&'w RemovedComponentMessages: ReadOnlySystemParam,
impl<'w, 's> ReadOnlySystemParam for Commands<'w, 's>
impl<'w, 's> ReadOnlySystemParam for ParallelCommands<'w, 's>where
Deferred<'s, ParallelCommandQueue>: ReadOnlySystemParam,
&'w EntityAllocator: ReadOnlySystemParam,
&'w Entities: ReadOnlySystemParam,
Available on crate feature
std only.