pub struct SparseSet<I, V: 'static> { /* private fields */ }Expand description
A map from I to V that combines dense and sparse storage.
This is implemented as a sparse array mapping keys to dense indexes, plus dense arrays of indexes and keys.
The key type, I, must implement SparseSetIndex
to allow conversion to and from array indexes.
This supports fast O(1) lookups, since they consist of one array index to map the key to a dense index, followed by a second array index to find the value.
This may use a lot of excess memory if the set is sparsely populated, since it stores an empty entry for each key.
Compared to a simple Vec<Option<V>>,
the dense storage of values takes less memory when V is large,
although the overhead of tracking which entries have values
may make it larger when V is small or the set is densely populated.
Implementations
Sourceimpl<I: SparseSetIndex, V> SparseSet<I, V>
impl<I: SparseSetIndex, V> SparseSet<I, V>
Sourcepub fn contains(&self, index: I) -> bool
pub fn contains(&self, index: I) -> bool
Returns true if the sparse set contains a value for index.
Sourcepub fn get(&self, index: I) -> Option<&V>
pub fn get(&self, index: I) -> Option<&V>
Returns a reference to the value for index.
Returns None if index does not have a value in the sparse set.
Sourcepub fn get_mut(&mut self, index: I) -> Option<&mut V>
pub fn get_mut(&mut self, index: I) -> Option<&mut V>
Returns a mutable reference to the value for index.
Returns None if index does not have a value in the sparse set.
Sourcepub fn indices(&self) -> &[I]
pub fn indices(&self) -> &[I]
Returns an iterator visiting all keys (indices) in arbitrary order.
Sourcepub fn values(&self) -> impl Iterator<Item = &V>
pub fn values(&self) -> impl Iterator<Item = &V>
Returns an iterator visiting all values in arbitrary order.
Sourcepub fn values_mut(&mut self) -> impl Iterator<Item = &mut V>
pub fn values_mut(&mut self) -> impl Iterator<Item = &mut V>
Returns an iterator visiting all values mutably in arbitrary order.
Sourceimpl<I: SparseSetIndex, V> SparseSet<I, V>
impl<I: SparseSetIndex, V> SparseSet<I, V>
Sourcepub fn with_capacity(capacity: usize) -> Self
pub fn with_capacity(capacity: usize) -> Self
Sourcepub fn capacity(&self) -> usize
pub fn capacity(&self) -> usize
Returns the total number of elements the SparseSet can hold without needing to reallocate.
Sourcepub fn insert(&mut self, index: I, value: V)
pub fn insert(&mut self, index: I, value: V)
Inserts value at index.
If a value was already present at index, it will be overwritten.
Panics
- Panics if the insertion forces an reallocation and the new capacity overflows
isize::MAXbytes. - Panics if the insertion forces an reallocation and causes an out-of-memory error.
Sourcepub fn get_or_insert_with(
&mut self,
index: I,
func: impl FnOnce() -> V,
) -> &mut V
pub fn get_or_insert_with( &mut self, index: I, func: impl FnOnce() -> V, ) -> &mut V
Returns a reference to the value for index, inserting one computed from func
if not already present.
Panics
- Panics if the insertion forces an reallocation and the new capacity overflows
isize::MAXbytes. - Panics if the insertion forces an reallocation and causes an out-of-memory error.